Behaviours: hank_rule.
To avoid this warning, remove the unused parameters.
For this rule to apply, it's assumed that configuration options for an Erlang application are only consumed within said Erlang application or the other applications in the same umbrella project. If you have a dependency that consumes an environment parameter from one of your project applications, you can add an ignore rule in rebar.config for it.
| analyze/2 | Detects unused config options. |
| ignored/2 | Rule ignore specifications. |
analyze(FilesAndASTs::hank_rule:asts(), Context::hank_context:t()) -> [hank_rule:result()]
Detects unused config options. It gets the options from .config and .app.src files and then:
ignored(Option::hank_rule:ignore_pattern(), X2::term()) -> boolean()
Rule ignore specifications. Only valid in rebar.config since attributes are not allowed in config files. Example:
{hank, [{ignore, [
{"this_file.config", unused_configuration_options, [ignore_option]}
]}]}.
Generated by EDoc