Behaviours: hank_rule.
To do
To avoid this warning, remove the unused header files.
This rule assumes that hrl files will not be used outside your project. If you are writing a library that requires your clients to use some of your header files, you can add an ignore rule in rebar.config for it.
| ignored/2 | It doesn't make sense to provide individual ignore spec support here. |
ignored(X1::hank_rule:ignore_pattern(), IgnoreSpec::term()) -> false
It doesn't make sense to provide individual ignore spec support here. The rule's basic unit is already a file.
Generated by EDoc